This is an automated email from the ASF dual-hosted git repository.

hxb pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/flink.git


The following commit(s) were added to refs/heads/master by this push:
     new d1e057a761a [FLINK-28546][python][release] Add the release logic for 
py39 and m1 wheel package
d1e057a761a is described below

commit d1e057a761ab69a5b157ee6034e9f1560ede15c2
Author: huangxingbo <[email protected]>
AuthorDate: Thu Jul 14 17:52:54 2022 +0800

    [FLINK-28546][python][release] Add the release logic for py39 and m1 wheel 
package
    
    This closes #20274.
---
 tools/releasing/create_binary_release.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tools/releasing/create_binary_release.sh 
b/tools/releasing/create_binary_release.sh
index cd7baf8403b..19650425082 100755
--- a/tools/releasing/create_binary_release.sh
+++ b/tools/releasing/create_binary_release.sh
@@ -129,8 +129,8 @@ make_python_release() {
   cp ${pyflink_actual_name} "${PYTHON_RELEASE_DIR}/${pyflink_release_name}"
 
   wheel_packages_num=0
-  # py36,py37,py38 for mac and linux (6 wheel packages)
-  EXPECTED_WHEEL_PACKAGES_NUM=6
+  # py36,py37,py38,py39 for mac and linux (10 wheel packages)
+  EXPECTED_WHEEL_PACKAGES_NUM=10
   # Need to move the downloaded wheel packages from Azure CI to the directory 
flink-python/dist manually.
   for wheel_file in *.whl; do
     if [[ ! ${wheel_file} =~ ^apache_flink-$PYFLINK_VERSION- ]]; then

Reply via email to